@@ -3,6 +3,14 @@
  * SPDX-License-Identifier: Apache-2.0
  */
 
+#![allow(clippy::derive_partial_eq_without_eq)]
+#![warn(
+    // missing_docs,
+    // rustdoc::missing_crate_level_docs,
+    unreachable_pub,
+    rust_2018_idioms
+)]
+
 pub mod dispatch;
 pub mod map_request;
 pub mod parse_response;
@@ -42,10 +50,10 @@ impl<E> From<SendOperationError> for SdkError<E> {
     fn from(err: SendOperationError) -> Self {
         match err {
             SendOperationError::RequestDispatchError(e) => {
-                aws_smithy_http::result::SdkError::DispatchFailure(e)
+                aws_smithy_http::result::SdkError::dispatch_failure(e)
             }
             SendOperationError::RequestConstructionError(e) => {
-                aws_smithy_http::result::SdkError::ConstructionFailure(e)
+                aws_smithy_http::result::SdkError::construction_failure(e)
             }
         }
     }
@@ -62,6 +70,7 @@ mod tests {
     use aws_smithy_http::operation::{Operation, Request};
     use aws_smithy_http::response::ParseStrictResponse;
     use aws_smithy_http::result::ConnectorError;
+    use aws_smithy_http::retry::DefaultResponseRetryClassifier;
     use bytes::Bytes;
     use http::Response;
     use std::convert::{Infallible, TryInto};
@@ -75,6 +84,11 @@ mod tests {
         struct AddHeader;
         impl MapRequest for AddHeader {
             type Error = Infallible;
+
+            fn name(&self) -> &'static str {
+                "add_header"
+            }
+
             fn apply(&self, request: Request) -> Result<Request, Self::Error> {
                 request.augment(|mut req, _| {
                     req.headers_mut()
@@ -102,7 +116,10 @@ mod tests {
         });
 
         let mut svc = ServiceBuilder::new()
-            .layer(ParseResponseLayer::<TestParseResponse, ()>::new())
+            .layer(ParseResponseLayer::<
+                TestParseResponse,
+                DefaultResponseRetryClassifier,
+            >::new())
             .layer(MapRequestLayer::for_mapper(AddHeader))
             .layer(DispatchLayer)
             .service(http_layer);
