@@ -8,14 +8,13 @@ use aws_smithy_http::middleware::load_response;
 use aws_smithy_http::operation;
 use aws_smithy_http::operation::Operation;
 use aws_smithy_http::response::ParseHttpResponse;
-use aws_smithy_http::result::SdkError;
+use aws_smithy_http::result::{SdkError, SdkSuccess};
 use std::future::Future;
 use std::marker::PhantomData;
 use std::pin::Pin;
 use std::task::{Context, Poll};
 use tower::{Layer, Service};
-use tracing::field::display;
-use tracing::{debug_span, field, info_span, Instrument};
+use tracing::{debug_span, Instrument};
 
 /// `ParseResponseService` dispatches [`Operation`](aws_smithy_http::operation::Operation)s and parses them.
 ///
@@ -67,7 +66,7 @@ type BoxedResultFuture<T, E> = Pin<Box<dyn Future<Output = Result<T, E>> + Send>
 /// `E`: The error path return of the response parser
 /// `R`: The type of the retry policy
 impl<InnerService, ResponseHandler, SuccessResponse, FailureResponse, RetryPolicy>
-    tower::Service<operation::Operation<ResponseHandler, RetryPolicy>>
+    Service<Operation<ResponseHandler, RetryPolicy>>
     for ParseResponseService<InnerService, ResponseHandler, RetryPolicy>
 where
     InnerService:
@@ -77,10 +76,10 @@ where
         + Send
         + Sync
         + 'static,
-    FailureResponse: std::error::Error,
+    FailureResponse: std::error::Error + 'static,
 {
-    type Response = aws_smithy_http::result::SdkSuccess<SuccessResponse>;
-    type Error = aws_smithy_http::result::SdkError<FailureResponse>;
+    type Response = SdkSuccess<SuccessResponse>;
+    type Error = SdkError<FailureResponse>;
     type Future = BoxedResultFuture<Self::Response, Self::Error>;
 
     fn poll_ready(&mut self, cx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
@@ -90,53 +89,17 @@ where
     fn call(&mut self, req: Operation<ResponseHandler, RetryPolicy>) -> Self::Future {
         let (req, parts) = req.into_request_response();
         let handler = parts.response_handler;
-        // send_operation records the full request-response lifecycle.
-        // NOTE: For operations that stream output, only the setup is captured in this span.
-        let span = info_span!(
-            "send_operation",
-            operation = field::Empty,
-            service = field::Empty,
-            status = field::Empty,
-            message = field::Empty
-        );
-        let inner_span = span.clone();
-        if let Some(metadata) = parts.metadata {
-            span.record("operation", &metadata.name());
-            span.record("service", &metadata.service());
-        }
         let resp = self.inner.call(req);
-        let fut = async move {
-            let resp = match resp.await {
+        Box::pin(async move {
+            match resp.await {
                 Err(e) => Err(e.into()),
                 Ok(resp) => {
-                    // load_response contains reading the body as far as is required & parsing the response
-                    let response_span = debug_span!("load_response");
                     load_response(resp, &handler)
-                        .instrument(response_span)
+                        // load_response contains reading the body as far as is required & parsing the response
+                        .instrument(debug_span!("load_response"))
                         .await
                 }
-            };
-            match &resp {
-                Ok(_) => inner_span.record("status", &"ok"),
-                Err(SdkError::ServiceError { err, .. }) => inner_span
-                    .record("status", &"service_err")
-                    .record("message", &display(&err)),
-                Err(SdkError::ResponseError { err, .. }) => inner_span
-                    .record("status", &"response_err")
-                    .record("message", &display(&err)),
-                Err(SdkError::DispatchFailure(err)) => inner_span
-                    .record("status", &"dispatch_failure")
-                    .record("message", &display(err)),
-                Err(SdkError::ConstructionFailure(err)) => inner_span
-                    .record("status", &"construction_failure")
-                    .record("message", &display(err)),
-                Err(SdkError::TimeoutError(err)) => inner_span
-                    .record("status", &"timeout_error")
-                    .record("message", &display(err)),
-            };
-            resp
-        }
-        .instrument(span);
-        Box::pin(fut)
+            }
+        })
     }
 }
